@@ -42,6 +42,8 @@ import java.util.Map;
  * CommandLine cl = new CommandLine("ls -l");
  * int exitvalue = exec.execute(cl);
  * </pre>
+ *
+ * @version $Id: Executor.java 1636056 2014-11-01 21:12:52Z ggregory $
  */
 
 public interface Executor {
@@ -50,7 +52,7 @@ public interface Executor {
     int INVALID_EXITVALUE = 0xdeadbeef;
 
     /**
-     * Define the <code>exitValue</code> of the process to be considered
+     * Define the {@code exitValue} of the process to be considered
      * successful. If a different exit value is returned by
      * the process then {@link org.apache.commons.exec.Executor#execute(CommandLine)}
      * will throw an {@link org.apache.commons.exec.ExecuteException} 
@@ -60,7 +62,7 @@ public interface Executor {
     void setExitValue(final int value);
 
     /**
-     * Define a list of <code>exitValue</code> of the process to be considered
+     * Define a list of {@code exitValue} of the process to be considered
      * successful. The caller can pass one of the following values
      * <ul>
      *  <li>an array of exit values to be considered successful</li>
@@ -77,13 +79,13 @@ public interface Executor {
     void setExitValues(final int[] values);
 
     /**
-     * Checks whether <code>exitValue</code> signals a failure. If no
+     * Checks whether {@code exitValue} signals a failure. If no
      * exit values are set than the default conventions of the OS is
      * used. e.g. most OS regard an exit code of '0' as successful
      * execution and everything else as failure.
      *
      * @param exitValue the exit value (return code) to be checked
-     * @return <code>true</code> if <code>exitValue</code> signals a failure
+     * @return {@code true} if {@code exitValue} signals a failure
      */
     boolean isFailure(final int exitValue);
 
@@ -177,7 +179,7 @@ public interface Executor {
      *          subprocess returned a exit value indicating a failure
      *          {@link Executor#setExitValue(int)}.
      */
-    int execute(CommandLine command, Map environment)
+    int execute(CommandLine command, Map<String, String> environment)
         throws ExecuteException, IOException;
     
     /**
@@ -203,6 +205,6 @@ public interface Executor {
      * @param handler capture process termination and exit code 
      * @throws ExecuteException execution of subprocess failed     
      */
-    void execute(CommandLine command, Map environment, ExecuteResultHandler handler)
+    void execute(CommandLine command, Map<String, String> environment, ExecuteResultHandler handler)
         throws ExecuteException, IOException;
 }
