@@ -18,31 +18,34 @@
 
 package org.apache.commons.exec;
 
+import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import java.io.File;
-import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
 
-import junit.framework.AssertionFailedError;
-import junit.framework.TestCase;
 import org.apache.commons.exec.util.StringUtils;
+import org.junit.Test;
 
-public class CommandLineTest extends TestCase {
+/**
+ * @version $Id: CommandLineTest.java 1636048 2014-11-01 20:55:54Z ggregory $
+ */
+public class CommandLineTest {
 
-    private void assertEquals(final String[] expected, final String[] actual) {
-        if (!Arrays.equals(expected, actual)) {
-            throw new AssertionFailedError("Arrays not equal");
-        }
-    }
 
+    @Test
     public void testExecutable() {
         final CommandLine cmdl = new CommandLine("test");
         assertEquals("[test]", cmdl.toString());
-        assertEquals(new String[] {"test"}, cmdl.toStrings());
+        assertArrayEquals(new String[]{"test"}, cmdl.toStrings());
         assertEquals("test", cmdl.getExecutable());
         assertTrue(cmdl.getArguments().length == 0);
     }
 
+    @Test
     public void testExecutableZeroLengthString() {
         try {
             new CommandLine("");
@@ -52,6 +55,7 @@ public class CommandLineTest extends TestCase {
         }
     }
 
+    @Test
     public void testExecutableWhitespaceString() {
         try {
             new CommandLine("   ");
@@ -61,6 +65,7 @@ public class CommandLineTest extends TestCase {
         }
     }
 
+    @Test
     public void testNullExecutable() {
         try {
             new CommandLine((String)null);
@@ -70,58 +75,65 @@ public class CommandLineTest extends TestCase {
         }
     }
 
+    @Test
     public void testAddArgument() {
         final CommandLine cmdl = new CommandLine("test");
 
         cmdl.addArgument("foo");
         cmdl.addArgument("bar");
         assertEquals("[test, foo, bar]", cmdl.toString());
-        assertEquals(new String[] {"test", "foo", "bar"}, cmdl.toStrings());
+        assertArrayEquals(new String[]{"test", "foo", "bar"}, cmdl.toStrings());
     }
 
+    @Test
     public void testAddNullArgument() {
         final CommandLine cmdl = new CommandLine("test");
 
         cmdl.addArgument(null);
         assertEquals("[test]", cmdl.toString());
-        assertEquals(new String[] {"test"}, cmdl.toStrings());
+        assertArrayEquals(new String[]{"test"}, cmdl.toStrings());
     }
 
+    @Test
     public void testAddArgumentWithSpace() {
         final CommandLine cmdl = new CommandLine("test");
         cmdl.addArgument("foo");
         cmdl.addArgument("ba r");
         assertEquals("[test, foo, \"ba r\"]", cmdl.toString());
-        assertEquals(new String[] {"test", "foo", "\"ba r\""}, cmdl.toStrings());
+        assertArrayEquals(new String[]{"test", "foo", "\"ba r\""}, cmdl.toStrings());
     }
 
+    @Test
     public void testAddArgumentWithQuote() {
         final CommandLine cmdl = new CommandLine("test");
         cmdl.addArgument("foo");
         cmdl.addArgument("ba\"r");
         assertEquals("[test, foo, 'ba\"r']", cmdl.toString());
-        assertEquals(new String[] {"test", "foo", "'ba\"r'"}, cmdl.toStrings());
+        assertArrayEquals(new String[]{"test", "foo", "'ba\"r'"}, cmdl.toStrings());
     }
 
+    @Test
     public void testAddArgumentWithQuotesAround() {
         final CommandLine cmdl = new CommandLine("test");
         cmdl.addArgument("\'foo\'");
         cmdl.addArgument("\"bar\"");
         cmdl.addArgument("\"fe z\"");
         assertEquals("[test, foo, bar, \"fe z\"]", cmdl.toString());
-        assertEquals(new String[] {"test", "foo", "bar", "\"fe z\""}, cmdl.toStrings());
+        assertArrayEquals(new String[]{"test", "foo", "bar", "\"fe z\""}, cmdl.toStrings());
     }
 
+    @Test
     public void testAddArgumentWithSingleQuote() {
         final CommandLine cmdl = new CommandLine("test");
 
         cmdl.addArgument("foo");
         cmdl.addArgument("ba'r");
         assertEquals("[test, foo, \"ba'r\"]", cmdl.toString());
-        assertEquals(new String[] {"test", "foo", "\"ba\'r\""}, cmdl
+        assertArrayEquals(new String[]{"test", "foo", "\"ba\'r\""}, cmdl
                 .toStrings());
     }
 
+    @Test
     public void testAddArgumentWithBothQuotes() {
         final CommandLine cmdl = new CommandLine("test");
 
@@ -133,40 +145,45 @@ public class CommandLineTest extends TestCase {
         }
     }
 
+    @Test
     public void testAddArguments() {
         final CommandLine cmdl = new CommandLine("test");
         cmdl.addArguments("foo bar");
         assertEquals("[test, foo, bar]", cmdl.toString());
-        assertEquals(new String[] {"test", "foo", "bar"}, cmdl.toStrings());
+        assertArrayEquals(new String[]{"test", "foo", "bar"}, cmdl.toStrings());
     }
 
+    @Test
     public void testAddArgumentsWithQuotes() {
         final CommandLine cmdl = new CommandLine("test");
         cmdl.addArguments("'foo' \"bar\"");
         assertEquals("[test, foo, bar]", cmdl.toString());
-        assertEquals(new String[] {"test", "foo", "bar"}, cmdl.toStrings());
+        assertArrayEquals(new String[]{"test", "foo", "bar"}, cmdl.toStrings());
     }
 
+    @Test
     public void testAddArgumentsWithQuotesAndSpaces() {
         final CommandLine cmdl = new CommandLine("test");
         cmdl.addArguments("'fo o' \"ba r\"");
         assertEquals("[test, \"fo o\", \"ba r\"]", cmdl.toString());
-        assertEquals(new String[] {"test", "\"fo o\"", "\"ba r\""}, cmdl
+        assertArrayEquals(new String[]{"test", "\"fo o\"", "\"ba r\""}, cmdl
                 .toStrings());
     }
 
+    @Test
     public void testAddArgumentsArray() {
         final CommandLine cmdl = new CommandLine("test");
         cmdl.addArguments(new String[] {"foo", "bar"});
         assertEquals("[test, foo, bar]", cmdl.toString());
-        assertEquals(new String[] {"test", "foo", "bar"}, cmdl.toStrings());
+        assertArrayEquals(new String[]{"test", "foo", "bar"}, cmdl.toStrings());
     }
 
+    @Test
     public void testAddArgumentsArrayNull() {
         final CommandLine cmdl = new CommandLine("test");
         cmdl.addArguments((String[]) null);
         assertEquals("[test]", cmdl.toString());
-        assertEquals(new String[] {"test"}, cmdl.toStrings());
+        assertArrayEquals(new String[]{"test"}, cmdl.toStrings());
     }
 
     /**
@@ -174,6 +191,7 @@ public class CommandLineTest extends TestCase {
      * in one line, e.g. to make commenting out some options
      * less error prone.
      */
+    @Test
     public void testAddTwoArguments() {
 
         final CommandLine userAddCL1 = new CommandLine("useradd");
@@ -188,18 +206,21 @@ public class CommandLineTest extends TestCase {
         assertEquals(userAddCL1.toString(), userAddCL2.toString());
     }
 
+    @Test
     public void testParseCommandLine() {
         final CommandLine cmdl = CommandLine.parse("test foo bar");
         assertEquals("[test, foo, bar]", cmdl.toString());
-        assertEquals(new String[] {"test", "foo", "bar"}, cmdl.toStrings());
+        assertArrayEquals(new String[]{"test", "foo", "bar"}, cmdl.toStrings());
     }
 
+    @Test
     public void testParseCommandLineWithQuotes() {
         final CommandLine cmdl = CommandLine.parse("test \"foo\" \'ba r\'");
         assertEquals("[test, foo, \"ba r\"]", cmdl.toString());
-        assertEquals(new String[] {"test", "foo", "\"ba r\""}, cmdl.toStrings());
+        assertArrayEquals(new String[]{"test", "foo", "\"ba r\""}, cmdl.toStrings());
     }
 
+    @Test
     public void testParseCommandLineWithUnevenQuotes() {
         try {
             CommandLine.parse("test \"foo bar");
@@ -209,6 +230,7 @@ public class CommandLineTest extends TestCase {
         }
     }
 
+    @Test
     public void testParseCommandLineWithNull() {
         try {
             CommandLine.parse(null);
@@ -218,6 +240,7 @@ public class CommandLineTest extends TestCase {
         }
     }
 
+    @Test
     public void testParseCommandLineWithOnlyWhitespace() {
         try {
             CommandLine.parse("  ");
@@ -233,8 +256,10 @@ public class CommandLineTest extends TestCase {
      * a "500x>" parameter (including quotes) and it is simply not possible to
      * do that without adding a space, e.g. "500x> ".
      */
+    @Test
     public void testParseComplexCommandLine1() {
-        final HashMap substitutionMap = new HashMap();
+        final HashMap<String, String> substitutionMap =
+            new HashMap<String, String>();
         substitutionMap.put("in", "source.jpg");
         substitutionMap.put("out", "target.jpg");
         final CommandLine cmdl = CommandLine.parse("cmd /C convert ${in} -resize \"\'500x> \'\" ${out}", substitutionMap);
@@ -246,6 +271,7 @@ public class CommandLineTest extends TestCase {
      * far as I understand it there is no way to express that
      * in a one-line command string.
      */
+    @Test
     public void testParseComplexCommandLine2() {
 
         final String commandline = "./script/jrake cruise:publish_installers "
@@ -268,6 +294,7 @@ public class CommandLineTest extends TestCase {
      *
      * cmd.exe /C c:\was51\Web Sphere\AppServer\bin\versionInfo.bat
      */
+    @Test
     public void testParseRealLifeCommandLine_1() {
 
         final String commandline = "cmd.exe /C \"c:\\was51\\Web Sphere\\AppServer\\bin\\versionInfo.bat\"";
@@ -282,23 +309,25 @@ public class CommandLineTest extends TestCase {
     * Create a command line with pre-quoted strings to test SANDBOX-192,
     * e.g. "runMemorySud.cmd", "10", "30", "-XX:+UseParallelGC", "\"-XX:ParallelGCThreads=2\""
     */
+   @Test
     public void testComplexAddArgument() {
         final CommandLine cmdl = new CommandLine("runMemorySud.cmd");
         cmdl.addArgument("10", false);
         cmdl.addArgument("30", false);
         cmdl.addArgument("-XX:+UseParallelGC", false);
         cmdl.addArgument("\"-XX:ParallelGCThreads=2\"", false);
-        assertEquals(new String[] {"runMemorySud.cmd", "10", "30", "-XX:+UseParallelGC", "\"-XX:ParallelGCThreads=2\""}, cmdl.toStrings());
+        assertArrayEquals(new String[]{"runMemorySud.cmd", "10", "30", "-XX:+UseParallelGC", "\"-XX:ParallelGCThreads=2\""}, cmdl.toStrings());
     }
 
     /**
      * Create a command line with pre-quoted strings to test SANDBOX-192,
      * e.g. "runMemorySud.cmd", "10", "30", "-XX:+UseParallelGC", "\"-XX:ParallelGCThreads=2\""
      */
+    @Test
      public void testComplexAddArguments1() {
          final CommandLine cmdl = new CommandLine("runMemorySud.cmd");
          cmdl.addArguments(new String[] {"10", "30", "-XX:+UseParallelGC", "\"-XX:ParallelGCThreads=2\""}, false);
-         assertEquals(new String[] {"runMemorySud.cmd", "10", "30", "-XX:+UseParallelGC", "\"-XX:ParallelGCThreads=2\""}, cmdl.toStrings());
+         assertArrayEquals(new String[]{"runMemorySud.cmd", "10", "30", "-XX:+UseParallelGC", "\"-XX:ParallelGCThreads=2\""}, cmdl.toStrings());
      }
 
     /**
@@ -307,49 +336,53 @@ public class CommandLineTest extends TestCase {
      * Please not that we re forced to add additional single quotes to get the test working -
      * don't know if this is a bug or a feature.
      */
+    @Test
      public void testComplexAddArguments2() {
          final CommandLine cmdl = new CommandLine("runMemorySud.cmd");
          cmdl.addArguments("10 30 -XX:+UseParallelGC '\"-XX:ParallelGCThreads=2\"'", false);
-         assertEquals(new String[] {"runMemorySud.cmd", "10", "30", "-XX:+UseParallelGC", "\"-XX:ParallelGCThreads=2\""}, cmdl.toStrings());
+         assertArrayEquals(new String[]{"runMemorySud.cmd", "10", "30", "-XX:+UseParallelGC", "\"-XX:ParallelGCThreads=2\""}, cmdl.toStrings());
      }
 
     /**
      * Test expanding the command line based on a user-supplied map.
      */
+    @Test
     public void testCommandLineParsingWithExpansion1() {
 
         CommandLine cmdl;
 
-        final HashMap substitutionMap = new HashMap();
+        final HashMap<String, Object> substitutionMap =
+            new HashMap<String, Object>();
         substitutionMap.put("JAVA_HOME", "/usr/local/java");
         substitutionMap.put("appMainClass", "foo.bar.Main");
         substitutionMap.put("file1", new File("./pom.xml"));
         substitutionMap.put("file2", new File(".\\temp\\READ ME.txt"));
 
-        final HashMap incompleteMap = new HashMap();
+        final HashMap<String, String> incompleteMap =
+            new HashMap<String, String>();
         incompleteMap.put("JAVA_HOME", "/usr/local/java");
 
         // do not pass substitution map
         cmdl = CommandLine.parse("${JAVA_HOME}/bin/java ${appMainClass}");
         assertTrue(cmdl.getExecutable().indexOf("${JAVA_HOME}") == 0 );
-        assertEquals(new String[] {"${appMainClass}"}, cmdl.getArguments());
+        assertArrayEquals(new String[]{"${appMainClass}"}, cmdl.getArguments());
 
         // pass arguments with an empty map
-        cmdl = CommandLine.parse("${JAVA_HOME}/bin/java ${appMainClass}", new HashMap());
+        cmdl = CommandLine.parse("${JAVA_HOME}/bin/java ${appMainClass}", new HashMap<String, Object>());
         assertTrue(cmdl.getExecutable().indexOf("${JAVA_HOME}") == 0 );
-        assertEquals(new String[] {"${appMainClass}"}, cmdl.getArguments());
+        assertArrayEquals(new String[]{"${appMainClass}"}, cmdl.getArguments());
 
         // pass an complete substitution map
         cmdl = CommandLine.parse("${JAVA_HOME}/bin/java ${appMainClass}", substitutionMap);
         assertTrue(cmdl.getExecutable().indexOf("${JAVA_HOME}") < 0 );
         assertTrue(cmdl.getExecutable().indexOf("local") > 0 );
-        assertEquals(new String[] {"foo.bar.Main"}, cmdl.getArguments());
+        assertArrayEquals(new String[]{"foo.bar.Main"}, cmdl.getArguments());
 
         // pass an incomplete substitution map resulting in unresolved variables
         cmdl = CommandLine.parse("${JAVA_HOME}/bin/java ${appMainClass}", incompleteMap);
         assertTrue(cmdl.getExecutable().indexOf("${JAVA_HOME}") < 0 );
         assertTrue(cmdl.getExecutable().indexOf("local") > 0 );
-        assertEquals(new String[] {"${appMainClass}"}, cmdl.getArguments());
+        assertArrayEquals(new String[]{"${appMainClass}"}, cmdl.getArguments());
 
         // pass a file
         cmdl = CommandLine.parse("${JAVA_HOME}/bin/java ${appMainClass} ${file1} ${file2}", substitutionMap);
@@ -361,13 +394,15 @@ public class CommandLineTest extends TestCase {
      * goal of the test is to setup a command line using macros and reuse
      * it multiple times.
      */
+    @Test
     public void testCommandLineParsingWithExpansion2() {
 
         CommandLine cmdl;
         String[] result;
 
         // build the user supplied parameters
-        final HashMap substitutionMap = new HashMap();
+        final HashMap<String, String> substitutionMap =
+            new HashMap<String, String>();
         substitutionMap.put("JAVA_HOME", "C:\\Programme\\jdk1.5.0_12");
         substitutionMap.put("appMainClass", "foo.bar.Main");
 
@@ -405,32 +440,34 @@ public class CommandLineTest extends TestCase {
         assertEquals(StringUtils.fixFileSeparatorChar("C:\\Programme\\jdk1.5.0_12\\bin\\java"), result[0]);
         assertEquals("-class", result[1]);
         assertEquals("foo.bar.Main", result[2]);
-        assertEquals("\"C:\\Document And Settings\\documents\\432432.pdf\"", result[3]);                
+        assertEquals("\"C:\\Document And Settings\\documents\\432432.pdf\"", result[3]);
     }
 
+    @Test
     public void testCommandLineParsingWithExpansion3() {
         final CommandLine cmdl = CommandLine.parse("AcroRd32.exe");
         cmdl.addArgument("/p");
         cmdl.addArgument("/h");
         cmdl.addArgument("${file}", false);
-        final HashMap params = new HashMap();
+        final HashMap<String, String> params = new HashMap<String, String>();
         params.put("file", "C:\\Document And Settings\\documents\\432432.pdf");
         cmdl.setSubstitutionMap(params);
         final String[] result = cmdl.toStrings();
         assertEquals("AcroRd32.exe", result[0]);
         assertEquals("/p", result[1]);
         assertEquals("/h", result[2]);
-        assertEquals("C:\\Document And Settings\\documents\\432432.pdf", result[3]);                
-        
+        assertEquals("C:\\Document And Settings\\documents\\432432.pdf", result[3]);
+
     }
     /**
      * Test the toString() method.
      *
      * @throws Exception the test failed
      */
+    @Test
     public void testToString() throws Exception {
         CommandLine cmdl;
-        final HashMap params = new HashMap();
+        final HashMap<String, String> params = new HashMap<String, String>();
 
         // use no arguments
         cmdl = CommandLine.parse("AcroRd32.exe", params);
@@ -452,6 +489,7 @@ public class CommandLineTest extends TestCase {
      *
      * @throws Exception the test failed
      */
+    @Test
     public void testToStringTroubleshooting() throws Exception {
         System.out.println("testToStringTroubleshooting");
         // On HP-UX quotes handling leads to errors,
@@ -467,69 +505,10 @@ public class CommandLineTest extends TestCase {
                 !cmd1.toString().equals(cmd2.toString()));
     }
 
-    /**
-     * Some complex real-life command line from
-     * http://blogs.msdn.com/b/astebner/archive/2005/12/13/503471.aspx
-     */
-    public void _testExec36_1() throws Exception {
-
-        CommandLine cmdl;
-
-        final String line = "./script/jrake "
-          + "cruise:publish_installers "
-          + "INSTALLER_VERSION=unstable_2_1 "
-          + "INSTALLER_PATH=\"/var/lib/cruise-agent/installers\" "
-          + "INSTALLER_DOWNLOAD_SERVER='something'"
-          + "WITHOUT_HELP_DOC=true";
-
-        cmdl = CommandLine.parse(line);
-        final String[] args = cmdl.toStrings();
-        assertEquals("./script/jrake", args[0]);
-        assertEquals("cruise:publish_installers", args[1]);
-        assertEquals("INSTALLER_VERSION=unstable_2_1", args[2]);
-        assertEquals("INSTALLER_PATH=\"/var/lib/cruise-agent/installers\"", args[3]);
-        assertEquals("INSTALLER_DOWNLOAD_SERVER='something'", args[4]);
-        assertEquals("WITHOUT_HELP_DOC=true", args[5]);
-    }
-
-    /**
-     * Some complex real-life command line from
-     * http://blogs.msdn.com/b/astebner/archive/2005/12/13/503471.aspx
-     */
-    public void _testExec36_2() {
-
-        CommandLine cmdl;
-
-        final String line = "dotnetfx.exe"
-                + " /q:a "
-                + "/c:\"install.exe /l \"\"c:\\Documents and Settings\\myusername\\Local Settings\\Temp\\netfx.log\"\" /q\"";
-
-        cmdl = CommandLine.parse(line);
-        final String[] args = cmdl.toStrings();
-        assertEquals("dotnetfx.exe", args[0]);
-        assertEquals("/q:a", args[1]);
-        assertEquals("/c:\"install.exe /l \"\"c:\\Documents and Settings\\myusername\\Local Settings\\Temp\\netfx.log\"\" /q\"", args[2] );
-    }
-
-    /**
-     * Test the following command line
-     *
-     * C:\CVS_DB\WeightsEngine /f WeightsEngine.mak CFG="WeightsEngine - Win32Release"
-     */
-    public void _testExec36_3() {
-
-        final String commandline = "C:\\CVS_DB\\WeightsEngine /f WeightsEngine.mak CFG=\"WeightsEngine - Win32Release\"";
-
-        final CommandLine cmdl = CommandLine.parse(commandline);
-        final String[] args = cmdl.getArguments();
-        assertEquals("/f", args[0]);
-        assertEquals("WeightsEngine.mak", args[1]);
-        assertEquals("CFG=\"WeightsEngine - Win32Release\"", args[2]);
-    }
-
+    @Test
     public void testCopyConstructor()
     {
-        final Map map = new HashMap();
+        final Map<String, String> map = new HashMap<String, String>();
         map.put("bar", "bar");
         final CommandLine other = new CommandLine("test");
         other.addArgument("foo");
@@ -537,7 +516,7 @@ public class CommandLineTest extends TestCase {
 
         final CommandLine cmdl = new CommandLine(other);
         assertEquals(other.getExecutable(), cmdl.getExecutable());
-        assertEquals(other.getArguments(), cmdl.getArguments());
+        assertArrayEquals(other.getArguments(), cmdl.getArguments());
         assertEquals(other.isFile(), cmdl.isFile());
         assertEquals(other.getSubstitutionMap(), cmdl.getSubstitutionMap());
 
